# Table of Contents

- [index](<./index.md>)
- [PortainerEE API (2.39.0)](<./PortainerEE-API-2.39.0.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#section/Authentication)Authentication](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionAuthenticationAuthentication.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#section/Security)Security](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionSecuritySecurity.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#section/Execute-Docker-requests)Execute Docker requests](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionExecute-Docker-requestsExecute-Docker-requests.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#section/Private-Registry)Private Registry](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0sectionPrivate-RegistryPrivate-Registry.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/auth)auth](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthauth.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/auth/operation/AuthenticateUser)Authenticate](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthoperationAuthenticateUserAuthenticate.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/auth/operation/Logout)Logout](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthoperationLogoutLogout.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/auth/operation/ValidateOAuth)Authenticate with OAuth](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauthoperationValidateOAuthAuthenticate-with-OAuth.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup)backup](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupbackup.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup/operation/Backup)Creates an archive with a system data snapshot that could be used to restore the system.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupCreates-an-archive-with-a-system-data-snapshot-that-could-be-used-to-restore-the-system..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup/operation/BackupToS3)Execute backup to AWS S3 Bucket](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupToS3Execute-backup-to-AWS-S3-Bucket.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup/operation/RestoreFromS3)Triggers a system restore using details of s3 backup](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationRestoreFromS3Triggers-a-system-restore-using-details-of-s3-backup.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup/operation/BackupSettingsFetch)Fetch s3 backup settings/configurations](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupSettingsFetchFetch-s3-backup-settingsconfigurations.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup/operation/UpdateS3Settings)Updates stored s3 backup settings and updates running cron jobs as needed](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationUpdateS3SettingsUpdates-stored-s3-backup-settings-and-updates-running-cron-jobs-as-needed.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup/operation/BackupStatusFetch)Fetch the status of the last scheduled backup run](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationBackupStatusFetchFetch-the-status-of-the-last-scheduled-backup-run.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/backup/operation/Restore)Triggers a system restore using provided backup file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagbackupoperationRestoreTriggers-a-system-restore-using-provided-backup-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates)custom_templates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatescustom_templates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateList)List available custom templates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateListList-available-custom-templates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateCreate)Create a custom template  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateCreate-a-custom-template--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateDelete)Remove a template](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateDeleteRemove-a-template.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateInspect)Inspect a custom template](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateInspectInspect-a-custom-template.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateUpdate)Update a template](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateUpdateUpdate-a-template.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateFile)Get Template stack file content.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateFileGet-Template-stack-file-content..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateGitFetch)Fetch the latest config file content based on custom template's git repository configuration](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateGitFetchFetch-the-latest-config-file-content-based-on-custom-templates-git-repository-configuration.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateCreateFile)Create a custom template](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateFileCreate-a-custom-template.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateCreateRepository)Create a custom template](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateRepositoryCreate-a-custom-template.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/custom_templates/operation/CustomTemplateCreateString)Create a custom template](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcustom_templatesoperationCustomTemplateCreateStringCreate-a-custom-template.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker)docker](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockerdocker.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/dockerContainerGpusInspect)Fetch container gpus data](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationdockerContainerGpusInspectFetch-container-gpus-data.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/containerImageStatus)Fetch image status for container](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationcontainerImageStatusFetch-image-status-for-container.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/containersImageStatusClear)Clear container image status cache](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationcontainersImageStatusClearClear-container-image-status-cache.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/dockerDashboard)Get counters for the dashboard](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationdockerDashboardGet-counters-for-the-dashboard.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/dockerImagesList)Fetch images](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationdockerImagesListFetch-images.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/ServiceImageStatus)Fetch image status for service](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationServiceImageStatusFetch-image-status-for-service.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/serviceImageStatusClear)Clear service image status cache](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationserviceImageStatusClearClear-service-image-status-cache.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/snapshotInspect)Fetch latest snapshot of environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationsnapshotInspectFetch-latest-snapshot-of-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/snapshotContainersList)Fetch containers list from a snapshot](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationsnapshotContainersListFetch-containers-list-from-a-snapshot.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/snapshotContainerInspect)Fetch container from a snapshot](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationsnapshotContainerInspectFetch-container-from-a-snapshot.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/docker/operation/stacksImageStatusClear)Clear stack image status cache](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagdockeroperationstacksImageStatusClearClear-stack-image-status-cache.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge)edge](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgeedge.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge/paths/~1endpoints~1{id}~1edge~1jobs~1{jobID}~1logs/post)Update the logs collected from an Edge Job](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgepaths1endpoints1id1edge1jobs1jobID1logspostUpdate-the-logs-collected-from-an-Edge-Job.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge/paths/~1endpoints~1{id}~1edge~1stacks~1{stackId}/get)Inspect an Edge Stack for an Environment(Endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgepaths1endpoints1id1edge1stacks1stackIdgetInspect-an-Edge-Stack-for-an-EnvironmentEndpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge/paths/~1endpoints~1edge~1generate-key/post)Generate an EdgeKey](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedgepaths1endpoints1edge1generate-keypostGenerate-an-EdgeKey.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_groups)edge_groups](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsedge_groups.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_groups/operation/EdgeGroupList)list EdgeGroups](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupListlist-EdgeGroups.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_groups/operation/EdgeGroupCreate)Create an EdgeGroup](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupCreateCreate-an-EdgeGroup.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_groups/operation/EdgeGroupDelete)Deletes an EdgeGroup](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupDeleteDeletes-an-EdgeGroup.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_groups/operation/EdgeGroupInspect)Inspects an EdgeGroup](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupInspectInspects-an-EdgeGroup.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_groups/operation/EdgeGroupUpdate)Updates an EdgeGroup](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_groupsoperationEdgeGroupUpdateUpdates-an-EdgeGroup.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs)edge_jobs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsedge_jobs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobList)Fetch EdgeJobs list](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobListFetch-EdgeJobs-list.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobDelete)Delete an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobDeleteDelete-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobInspect)Inspect an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobInspectInspect-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobUpdate)Update an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobUpdateUpdate-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobFile)Fetch a file of an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobFileFetch-a-file-of-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobTasksList)Fetch the list of tasks on an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTasksListFetch-the-list-of-tasks-on-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobTasksClear)Clear the log for a specifc task on an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTasksClearClear-the-log-for-a-specifc-task-on-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobTaskLogsInspect)Fetch the log for a specifc task on an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTaskLogsInspectFetch-the-log-for-a-specifc-task-on-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobTasksCollect)Collect the log for a specifc task on an EdgeJob](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobTasksCollectCollect-the-log-for-a-specifc-task-on-an-EdgeJob.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobCreateFile)Create an EdgeJob from a file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobCreateFileCreate-an-EdgeJob-from-a-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_jobs/operation/EdgeJobCreateString)Create an EdgeJob from a text](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_jobsoperationEdgeJobCreateStringCreate-an-EdgeJob-from-a-text.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks)edge_stacks](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksedge_stacks.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackList)Fetches the list of EdgeStacks](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackListFetches-the-list-of-EdgeStacks.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackDelete)Delete an EdgeStack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackDeleteDelete-an-EdgeStack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackInspect)Inspect an EdgeStack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackInspectInspect-an-EdgeStack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackUpdate)Update an EdgeStack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackUpdateUpdate-an-EdgeStack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackFile)Fetches the stack file for an EdgeStack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackFileFetches-the-stack-file-for-an-EdgeStack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/edgeStackUpdateFromGit)Update git configuration and pulls the repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationedgeStackUpdateFromGitUpdate-git-configuration-and-pulls-the-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackLogsDelete)Deletes the available logs for a given edge stack and endpoint](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsDeleteDeletes-the-available-logs-for-a-given-edge-stack-and-endpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackLogsStatusGet)Gets the status of the log collection for a given edgestack and environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsStatusGetGets-the-status-of-the-log-collection-for-a-given-edgestack-and-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackLogsCollect)Schedule the collection of logs for a given endpoint and edge stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsCollectSchedule-the-collection-of-logs-for-a-given-endpoint-and-edge-stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackLogsDownload)Downloads the available logs for a given edge stack and endpoint](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackLogsDownloadDownloads-the-available-logs-for-a-given-edge-stack-and-endpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackStaggerStatusInspect)Inspect an EdgeStack's parallel update status](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackStaggerStatusInspectInspect-an-EdgeStacks-parallel-update-status.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackStatusUpdate)Update an EdgeStack status](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackStatusUpdateUpdate-an-EdgeStack-status.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackCreateFile)Create an EdgeStack from file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackCreateFileCreate-an-EdgeStack-from-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackCreateRepository)Create an EdgeStack from a git repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackCreateRepositoryCreate-an-EdgeStack-from-a-git-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackCreateString)Create an EdgeStack from a text](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackCreateStringCreate-an-EdgeStack-from-a-text.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackParseRegistries)Parse registries from a stack file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stacksoperationEdgeStackParseRegistriesParse-registries-from-a-stack-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/paths/~1endpoints~1{id}~1edge~1stacks~1{stackId}/get)Inspect an Edge Stack for an Environment(Endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_stackspaths1endpoints1id1edge1stacks1stackIdgetInspect-an-Edge-Stack-for-an-EnvironmentEndpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_templates)edge_templates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_templatesedge_templates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups)endpoint_groups](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsendpoint_groups.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups/operation/EndpointGroupList)List Environment(Endpoint) groups](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupListList-EnvironmentEndpoint-groups.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups/paths/~1endpoint_groups/post)Create an Environment(Endpoint) Group](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupspaths1endpoint_groupspostCreate-an-EnvironmentEndpoint-Group.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups/operation/EndpointGroupDelete)Remove an environment(endpoint) group](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupDeleteRemove-an-environmentendpoint-group.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups/paths/~1endpoint_groups~1{id}/get)Inspect an Environment(Endpoint) group](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupspaths1endpoint_groups1idgetInspect-an-EnvironmentEndpoint-group.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups/operation/EndpointGroupUpdate)Update an environment(endpoint) group](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupUpdateUpdate-an-environmentendpoint-group.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups/operation/EndpointGroupDeleteEndpoint)Removes environment(endpoint) from an environment(endpoint) group](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupDeleteEndpointRemoves-environmentendpoint-from-an-environmentendpoint-group.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoint_groups/operation/EndpointGroupAddEndpoint)Add an environment(endpoint) to an environment(endpoint) group](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpoint_groupsoperationEndpointGroupAddEndpointAdd-an-environmentendpoint-to-an-environmentendpoint-group.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints)endpoints](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsendpoints.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/snapshotInspect)Fetch latest snapshot of environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationsnapshotInspectFetch-latest-snapshot-of-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/snapshotContainersList)Fetch containers list from a snapshot](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationsnapshotContainersListFetch-containers-list-from-a-snapshot.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/snapshotContainerInspect)Fetch container from a snapshot](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationsnapshotContainerInspectFetch-container-from-a-snapshot.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointDeleteBatchDeprecated)Remove multiple environments  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointDeleteBatchDeprecatedRemove-multiple-environments--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointList)List environments(endpoints)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointListList-environmentsendpoints.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointCreate)Create a new environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointCreateCreate-a-new-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointDelete)Remove an environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointDeleteRemove-an-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointInspect)Inspect an environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointInspectInspect-an-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointUpdate)Update an environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointUpdateUpdate-an-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointAssociationDelete)De-association an edge environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointAssociationDeleteDe-association-an-edge-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/paths/~1endpoints~1{id}~1docker~1v2~1browse~1put/post)Upload a file under a specific path on the file system of an environment (endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1id1docker1v21browse1putpostUpload-a-file-under-a-specific-path-on-the-file-system-of-an-environment-endpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/endpointDockerhubStatus)fetch docker pull limits](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointDockerhubStatusfetch-docker-pull-limits.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointGetCharts)Get environment(endpoint) charts to install](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointGetChartsGet-environmentendpoint-charts-to-install.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointUpdateChartStatuses)Update environment(endpoint) policy chart installation statuses](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointUpdateChartStatusesUpdate-environmentendpoint-policy-chart-installation-statuses.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/paths/~1endpoints~1{id}~1edge~1jobs~1{jobID}~1logs/post)Update the logs collected from an Edge Job](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1id1edge1jobs1jobID1logspostUpdate-the-logs-collected-from-an-Edge-Job.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/paths/~1endpoints~1{id}~1edge~1stacks~1{stackId}/get)Inspect an Edge Stack for an Environment(Endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1id1edge1stacks1stackIdgetInspect-an-Edge-Stack-for-an-EnvironmentEndpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointEdgeStatusInspect)Get environment(endpoint) status](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointEdgeStatusInspectGet-environmentendpoint-status.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/endpointForceUpdateService)force update a docker service](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointForceUpdateServiceforce-update-a-docker-service.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointMTLSCertificate)Get an environment(endpoint) mTLS certificate](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointMTLSCertificateGet-an-environmentendpoint-mTLS-certificate.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointMTLSAgentCertificateError)Get an agent(endpoint) mTLS certificate](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointMTLSAgentCertificateErrorGet-an-agentendpoint-mTLS-certificate.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/namespacesAccessUpdate)Update namespace access for a given namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationnamespacesAccessUpdateUpdate-namespace-access-for-a-given-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/endpointRegistriesList)List Registries on environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointRegistriesListList-Registries-on-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/endpointRegistryAccess)update registry access for environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointRegistryAccessupdate-registry-access-for-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointSettingsUpdate)Update settings for an environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointSettingsUpdateUpdate-settings-for-an-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointSnapshot)Snapshots an environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointSnapshotSnapshots-an-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/AgentVersions)List agent versions](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationAgentVersionsList-agent-versions.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointDeleteBatch)Remove multiple environments](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointDeleteBatchRemove-multiple-environments.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/endpointEdgeAsync)Get environment(endpoint) status](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationendpointEdgeAsyncGet-environmentendpoint-status.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/paths/~1endpoints~1edge~1generate-key/post)Generate an EdgeKey](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointspaths1endpoints1edge1generate-keypostGenerate-an-EdgeKey.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/TrustEdgeEndpoints)Associate one or more Edge environments in the waiting room to environments](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationTrustEdgeEndpointsAssociate-one-or-more-Edge-environments-in-the-waiting-room-to-environments.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointCreateGlobalKey)Create or retrieve the endpoint for an EdgeID](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointCreateGlobalKeyCreate-or-retrieve-the-endpoint-for-an-EdgeID.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointUpdateRelations)Update relations for a list of environments](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointUpdateRelationsUpdate-relations-for-a-list-of-environments.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointSnapshots)Snapshot all environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagendpointsoperationEndpointSnapshotsSnapshot-all-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/gitops)gitops](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsgitops.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/gitops/operation/GitOperationRepoFilePreview)preview the content of target file in the git repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoFilePreviewpreview-the-content-of-target-file-in-the-git-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/gitops/operation/GitOperationRepoFilesSearch)Search the file path from a git repository files with specified extensions](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoFilesSearchSearch-the-file-path-from-a-git-repository-files-with-specified-extensions.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/gitops/operation/GitOperationRepoHelmValues)Preview merged Helm values files from git repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoHelmValuesPreview-merged-Helm-values-files-from-git-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/gitops/operation/GitOperationRepoRefs)List the refs of a git repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taggitopsoperationGitOperationRepoRefsList-the-refs-of-a-git-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm)helm](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmhelm.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmList)List Helm Releases](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmListList-Helm-Releases.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmInstall)Install Helm Chart](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmInstallInstall-Helm-Chart.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmGet)Get a helm release](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmGetGet-a-helm-release.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmDelete)Delete Helm Release](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmDeleteDelete-Helm-Release.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmGetHistory)Get a historical list of releases](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmGetHistoryGet-a-historical-list-of-releases.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmRollback)Rollback a helm release](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmRollbackRollback-a-helm-release.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmGitDryRun)Helm Git Dry Run](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmGitDryRunHelm-Git-Dry-Run.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmRepoSearch)Search Helm Charts](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmRepoSearchSearch-Helm-Charts.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmShow)Show Helm Chart Information](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmShowShow-Helm-Chart-Information.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmUserRepositoriesList)List a users helm repositories](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmUserRepositoriesListList-a-users-helm-repositories.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmUserRepositoryCreate)Create a user helm repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmUserRepositoryCreateCreate-a-user-helm-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/helm/operation/HelmUserRepositoryDelete)Delete a users helm repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taghelmoperationHelmUserRepositoryDeleteDelete-a-users-helm-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/intel)intel](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagintelintel.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/intel/operation/OpenAMTConfigure)Enable Portainer's OpenAMT capabilities  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationOpenAMTConfigureEnable-Portainers-OpenAMT-capabilities--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/intel/operation/openAMTActivate)Activate OpenAMT device and associate to agent endpoint  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationopenAMTActivateActivate-OpenAMT-device-and-associate-to-agent-endpoint--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/intel/operation/OpenAMTDevices)Fetch OpenAMT managed devices information for endpoint  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationOpenAMTDevicesFetch-OpenAMT-managed-devices-information-for-endpoint--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/intel/operation/DeviceAction)Execute out of band action on an AMT managed device  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationDeviceActionExecute-out-of-band-action-on-an-AMT-managed-device--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/intel/operation/DeviceFeatures)Enable features on an AMT managed device  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationDeviceFeaturesEnable-features-on-an-AMT-managed-device--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/intel/operation/OpenAMTHostInfo)Request OpenAMT info from a node  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taginteloperationOpenAMTHostInfoRequest-OpenAMT-info-from-a-node--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas)kaas](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaaskaas.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/providerInfo)Get information about the provisioning options for a cloud provider.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationproviderInfoGet-information-about-the-provisioning-options-for-a-cloud-provider..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/provisionCluster)Provision a new CIVO, Linode or Digital Ocean cluster and create an environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterProvision-a-new-CIVO-Linode-or-Digital-Ocean-cluster-and-create-an-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/provisionClusterAmazon)Provision a new Amazon EKS and create an environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterAmazonProvision-a-new-Amazon-EKS-and-create-an-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/provisionClusterAzure)Provision a new Microsoft Azure cluster and create an environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterAzureProvision-a-new-Microsoft-Azure-cluster-and-create-an-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/microk8sGetAddons)Get a list of addons which are installed in a MicroK8s cluster.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationmicrok8sGetAddonsGet-a-list-of-addons-which-are-installed-in-a-MicroK8s-cluster..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/microk8sUpdateAddons)Get a list of addons which are installed in a MicroK8s cluster.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationmicrok8sUpdateAddonsGet-a-list-of-addons-which-are-installed-in-a-MicroK8s-cluster..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/addNodes)Add nodes to the cluster (scale up).](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationaddNodesAdd-nodes-to-the-cluster-scale-up..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/microk8sGetNodeStatus)Get the MicroK8s status for a control plane node.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationmicrok8sGetNodeStatusGet-the-MicroK8s-status-for-a-control-plane-node..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/removeNodes)Remove nodes from the cluster and uninstall MicroK8s from them.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationremoveNodesRemove-nodes-from-the-cluster-and-uninstall-MicroK8s-from-them..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/upgrade)Upgrade the cluster to the next stable kubernetes version.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationupgradeUpgrade-the-cluster-to-the-next-stable-kubernetes-version..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/kaasVersion)Get the current cluster version.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationkaasVersionGet-the-current-cluster-version..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/provisionClusterGKE)Provision a new Google Kubernetes (GKE) cluster and create an environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationprovisionClusterGKEProvision-a-new-Google-Kubernetes-GKE-cluster-and-create-an-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kaas/operation/testSSH)Test SSH connection to nodes](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkaasoperationtestSSHTest-SSH-connection-to-nodes.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes)kubernetes](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkuberneteskubernetes.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getKubernetesPodSecurityRule)Get Pod Security Rule within k8s cluster, if not found, the frontend will create a default](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesPodSecurityRuleGet-Pod-Security-Rule-within-k8s-cluster-if-not-found-the-frontend-will-create-a-default.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/updateK8sPodSecurityRule)Update Pod Security Rule within k8s cluster](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationupdateK8sPodSecurityRuleUpdate-Pod-Security-Rule-within-k8s-cluster.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesApplications)Get a list of applications across all namespaces in the cluster. If the nodeName is provided, it will return the applications running on that node.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesApplicationsGet-a-list-of-applications-across-all-namespaces-in-the-cluster.-If-the-nodeName-is-provided-it-will-return-the-applications-running-on-that-node..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getAllKubernetesApplicationsCount)Get Applications count](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetAllKubernetesApplicationsCountGet-Applications-count.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteClusterRoleBindings)Delete cluster role bindings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteClusterRoleBindingsDelete-cluster-role-bindings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteClusterRoles)Delete cluster roles](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteClusterRolesDelete-cluster-roles.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesClusterRoleBindings)Get a list of kubernetes cluster role bindings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterRoleBindingsGet-a-list-of-kubernetes-cluster-role-bindings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesClusterRoles)Get a list of kubernetes cluster roles](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterRolesGet-a-list-of-kubernetes-cluster-roles.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesConfigMaps)Get a list of ConfigMaps](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesConfigMapsGet-a-list-of-ConfigMaps.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesConfigMapsCount)Get ConfigMaps count](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesConfigMapsCountGet-ConfigMaps-count.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesCronJobs)Get a list of kubernetes Cron Jobs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesCronJobsGet-a-list-of-kubernetes-Cron-Jobs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteCronJobs)Delete Cron Jobs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteCronJobsDelete-Cron-Jobs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getKubernetesCustomResourceDefinitions)Get a list of kubernetes Custom Resource Definitions](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesCustomResourceDefinitionsGet-a-list-of-kubernetes-Custom-Resource-Definitions.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/deleteKubernetesCustomResourceDefinition)Delete a kubernetes Custom Resource Definition](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdeleteKubernetesCustomResourceDefinitionDelete-a-kubernetes-Custom-Resource-Definition.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getKubernetesCustomResourceDefinition)Get a kubernetes Custom Resource Definition](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesCustomResourceDefinitionGet-a-kubernetes-Custom-Resource-Definition.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getKubernetesAllCustomResources)Get a list of kubernetes Custom Resources](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesAllCustomResourcesGet-a-list-of-kubernetes-Custom-Resources.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/deleteKubernetesClusterScopedCustomResource)Delete a cluster-scoped kubernetes Custom Resource](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdeleteKubernetesClusterScopedCustomResourceDelete-a-cluster-scoped-kubernetes-Custom-Resource.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getKubernetesClusterScopedCustomResource)Get a cluster-scoped kubernetes Custom Resource](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesClusterScopedCustomResourceGet-a-cluster-scoped-kubernetes-Custom-Resource.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/deleteKubernetesNamespacedCustomResource)Delete a namespaced kubernetes Custom Resource](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdeleteKubernetesNamespacedCustomResourceDelete-a-namespaced-kubernetes-Custom-Resource.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getKubernetesNamespacedCustomResource)Get a list of kubernetes Custom Resources](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesNamespacedCustomResourceGet-a-list-of-kubernetes-Custom-Resources.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesDashboard)Get the dashboard summary data](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesDashboardGet-the-dashboard-summary-data.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DescribeResource)Get a description of a kubernetes resource](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDescribeResourceGet-a-description-of-a-kubernetes-resource.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getAllKubernetesEvents)Gets kubernetes events](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetAllKubernetesEventsGets-kubernetes-events.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesIngressControllers)Get a list of ingress controllers](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesIngressControllersGet-a-list-of-ingress-controllers.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/UpdateKubernetesIngressControllers)Update (block/unblock) ingress controllers](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesIngressControllersUpdate-blockunblock-ingress-controllers.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesClusterIngresses)Get kubernetes ingresses at the cluster level](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterIngressesGet-kubernetes-ingresses-at-the-cluster-level.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesClusterIngressesCount)Get Ingresses count](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesClusterIngressesCountGet-Ingresses-count.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteKubernetesIngresses)Delete one or more Ingresses](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteKubernetesIngressesDelete-one-or-more-Ingresses.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesJobs)Get a list of kubernetes Jobs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesJobsGet-a-list-of-kubernetes-Jobs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteJobs)Delete Jobs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteJobsDelete-Jobs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesMaxResourceLimits)Get max CPU and memory limits of all nodes within k8s cluster](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMaxResourceLimitsGet-max-CPU-and-memory-limits-of-all-nodes-within-k8s-cluster.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetApplicationsResources)Get the total CPU (cores) and memory requests (MB) and limits of all applications across all namespaces](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetApplicationsResourcesGet-the-total-CPU-cores-and-memory-requests-MB-and-limits-of-all-applications-across-all-namespaces.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesMetricsForAllNodes)Get a list of nodes with their live metrics](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForAllNodesGet-a-list-of-nodes-with-their-live-metrics.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesMetricsForNode)Get live metrics for a node](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForNodeGet-live-metrics-for-a-node.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesMetricsForAllPods)Get a list of pods with their live metrics](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForAllPodsGet-a-list-of-pods-with-their-live-metrics.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesMetricsForPod)Get live metrics for a pod](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesMetricsForPodGet-live-metrics-for-a-pod.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteKubernetesNamespace)Delete a kubernetes namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteKubernetesNamespaceDelete-a-kubernetes-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesNamespaces)Get a list of namespaces](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNamespacesGet-a-list-of-namespaces.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/CreateKubernetesNamespace)Create a namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationCreateKubernetesNamespaceCreate-a-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/UpdateKubernetesNamespaceDeprecated)Update a namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesNamespaceDeprecatedUpdate-a-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesNamespace)Get namespace details](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNamespaceGet-namespace-details.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/UpdateKubernetesNamespace)Update a namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesNamespaceUpdate-a-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/restartKubernetesApplication)Restart a Kubernetes application](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationrestartKubernetesApplicationRestart-a-Kubernetes-application.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesApplication)Get an application by name in a specific namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesApplicationGet-an-application-by-name-in-a-specific-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesConfigMap)Get a ConfigMap](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesConfigMapGet-a-ConfigMap.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getKubernetesEventsForNamespace)Gets kubernetes events for namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetKubernetesEventsForNamespaceGets-kubernetes-events-for-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesIngressControllersByNamespace)Get a list ingress controllers by namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesIngressControllersByNamespaceGet-a-list-ingress-controllers-by-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/UpdateKubernetesIngressControllersByNamespace)Update (block/unblock) ingress controllers by namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesIngressControllersByNamespaceUpdate-blockunblock-ingress-controllers-by-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesIngresses)Get a list of Ingresses](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesIngressesGet-a-list-of-Ingresses.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/CreateKubernetesIngress)Create an Ingress](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationCreateKubernetesIngressCreate-an-Ingress.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/UpdateKubernetesIngress)Update an Ingress](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesIngressUpdate-an-Ingress.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesIngress)Get an Ingress by name](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesIngressGet-an-Ingress-by-name.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesSecret)Get a Secret](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesSecretGet-a-Secret.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesServicesByNamespace)Get a list of services for a given namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesServicesByNamespaceGet-a-list-of-services-for-a-given-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/CreateKubernetesService)Create a service](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationCreateKubernetesServiceCreate-a-service.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/UpdateKubernetesService)Update a service](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationUpdateKubernetesServiceUpdate-a-service.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/KubernetesNamespacesToggleSystem)Toggle the system state for a namespace](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationKubernetesNamespacesToggleSystemToggle-the-system-state-for-a-namespace.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesVolumesInNamespace)Get Kubernetes volumes within a namespace in the given Portainer environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesVolumesInNamespaceGet-Kubernetes-volumes-within-a-namespace-in-the-given-Portainer-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesNamespacesCount)Get the total number of kubernetes namespaces within the given Portainer environment.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNamespacesCountGet-the-total-number-of-kubernetes-namespaces-within-the-given-Portainer-environment..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/drainNode)Drain a Kubernetes node](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationdrainNodeDrain-a-Kubernetes-node.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesNodesLimits)Get CPU and memory limits of all nodes within k8s cluster.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesNodesLimitsGet-CPU-and-memory-limits-of-all-nodes-within-k8s-cluster..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesRBACStatus)Check if RBAC is enabled](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesRBACStatusCheck-if-RBAC-is-enabled.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteRoleBindings)Delete role bindings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteRoleBindingsDelete-role-bindings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesRoleBindings)Get a list of kubernetes role bindings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesRoleBindingsGet-a-list-of-kubernetes-role-bindings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesRoles)Get a list of kubernetes roles](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesRolesGet-a-list-of-kubernetes-roles.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteRoles)Delete roles](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteRolesDelete-roles.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesSecrets)Get a list of Secrets](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesSecretsGet-a-list-of-Secrets.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesSecretsCount)Get Secrets count](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesSecretsCountGet-Secrets-count.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteServiceAccounts)Delete service accounts](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteServiceAccountsDelete-service-accounts.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesServiceAccounts)Get a list of kubernetes service accounts](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesServiceAccountsGet-a-list-of-kubernetes-service-accounts.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesServices)Get a list of services](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesServicesGet-a-list-of-services.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesServicesCount)Get services count](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesServicesCountGet-services-count.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/DeleteKubernetesServices)Delete services](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationDeleteKubernetesServicesDelete-services.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetAllKubernetesVolumes)Get Kubernetes volumes within the given Portainer environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetAllKubernetesVolumesGet-Kubernetes-volumes-within-the-given-Portainer-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/GetKubernetesVolume)Get a Kubernetes volume within the given Portainer environment](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationGetKubernetesVolumeGet-a-Kubernetes-volume-within-the-given-Portainer-environment.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/kubernetes/operation/getAllKubernetesVolumesCount)Get the total number of kubernetes volumes within the given Portainer environment.](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagkubernetesoperationgetAllKubernetesVolumesCountGet-the-total-number-of-kubernetes-volumes-within-the-given-Portainer-environment..md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ldap)ldap](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapldap.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ldap/operation/LDAPAdminGroups)Fetch LDAP admin groups](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPAdminGroupsFetch-LDAP-admin-groups.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ldap/operation/LDAPCheck)Test LDAP connectivity](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPCheckTest-LDAP-connectivity.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ldap/operation/LDAPGroups)Search LDAP Groups](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPGroupsSearch-LDAP-Groups.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ldap/operation/LDAPTestLogin)Test Login to ldap server](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPTestLoginTest-Login-to-ldap-server.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ldap/operation/LDAPUsers)Search LDAP Users](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagldapoperationLDAPUsersSearch-LDAP-Users.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/metrics)metrics](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagmetricsmetrics.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/motd)motd](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagmotdmotd.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/motd/operation/MOTD)fetches the message of the day](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagmotdoperationMOTDfetches-the-message-of-the-day.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries)registries](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesregistries.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RegistryList)List Registries](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryListList-Registries.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RegistryCreate)Create a new registry](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryCreateCreate-a-new-registry.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RegistryDelete)Remove a registry](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryDeleteRemove-a-registry.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RegistryInspect)Inspect a registry](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryInspectInspect-a-registry.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RegistryUpdate)Update a registry](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryUpdateUpdate-a-registry.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RegistryConfigure)Configures a registry](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryConfigureConfigures-a-registry.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/ecrDeleteRepository)Delete ECR repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationecrDeleteRepositoryDelete-ECR-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/ecrDeleteTags)Delete tags](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationecrDeleteTagsDelete-tags.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RepositoryTagsDelete)Delete repository tags](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRepositoryTagsDeleteDelete-repository-tags.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/registries/operation/RegistryPing)Test registry connection](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagregistriesoperationRegistryPingTest-registry-connection.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/resource_controls)resource_controls](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsresource_controls.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/resource_controls/operation/ResourceControlCreate)Create a new resource control](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsoperationResourceControlCreateCreate-a-new-resource-control.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/resource_controls/operation/ResourceControlDelete)Remove a resource control](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsoperationResourceControlDeleteRemove-a-resource-control.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/resource_controls/operation/ResourceControlUpdate)Update a resource control](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagresource_controlsoperationResourceControlUpdateUpdate-a-resource-control.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/roles)roles](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagrolesroles.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/roles/operation/RoleList)List roles](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagrolesoperationRoleListList-roles.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings)settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingssettings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsInspect)Retrieve Portainer settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsInspectRetrieve-Portainer-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsUpdate)Update Portainer settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsUpdateUpdate-Portainer-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsAdditionalFunctionalityInspect)Retrieve Portainer additional functionality settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsAdditionalFunctionalityInspectRetrieve-Portainer-additional-functionality-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsAdditionalFunctionalityUpdate)Update Portainer additional functionality settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsAdditionalFunctionalityUpdateUpdate-Portainer-additional-functionality-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/DefaultRegistryUpdate)Update Portainer default registry settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationDefaultRegistryUpdateUpdate-Portainer-default-registry-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsEdgeMTLSCACertificates)Retrieve Portainer Edge MTLS CA Certificates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsEdgeMTLSCACertificatesRetrieve-Portainer-Edge-MTLS-CA-Certificates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsEdgeMTLSCertificates)Retrieve Portainer Edge MTLS Certificates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsEdgeMTLSCertificatesRetrieve-Portainer-Edge-MTLS-Certificates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsExperimentalInspect)Retrieve Portainer experimental settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsExperimentalInspectRetrieve-Portainer-experimental-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsExperimentalUpdate)Update Portainer experimental settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsExperimentalUpdateUpdate-Portainer-experimental-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsPublic)Retrieve Portainer public settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsettingsoperationSettingsPublicRetrieve-Portainer-public-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks)stacks](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksstacks.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/EdgeStackWebhookInvoke)Webhook for triggering edge stack updates from git](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationEdgeStackWebhookInvokeWebhook-for-triggering-edge-stack-updates-from-git.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackList)List stacks](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackListList-stacks.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackDelete)Remove a stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackDeleteRemove-a-stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackInspect)Inspect a stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackInspectInspect-a-stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackUpdate)Update a stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackUpdateUpdate-a-stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackAssociate)Associate an orphaned stack to a new environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackAssociateAssociate-an-orphaned-stack-to-a-new-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackFileInspect)Retrieve the content of the Stack file for the specified stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackFileInspectRetrieve-the-content-of-the-Stack-file-for-the-specified-stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackUpdateGit)Update a stack's Git configs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackUpdateGitUpdate-a-stacks-Git-configs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackGitRedeploy)Redeploy a stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackGitRedeployRedeploy-a-stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/stackImagesStatus)Fetch image status for stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationstackImagesStatusFetch-image-status-for-stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackMigrate)Migrate a stack to another environment(endpoint)](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackMigrateMigrate-a-stack-to-another-environmentendpoint.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackStart)Starts a stopped Stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackStartStarts-a-stopped-Stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackStop)Stops a stopped Stack](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackStopStops-a-stopped-Stack.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateKubernetesGit)Deploy a new kubernetes stack from a git repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateKubernetesGitDeploy-a-new-kubernetes-stack-from-a-git-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateKubernetesFile)Deploy a new kubernetes stack from a file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateKubernetesFileDeploy-a-new-kubernetes-stack-from-a-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateKubernetesUrl)Deploy a new kubernetes stack from a url](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateKubernetesUrlDeploy-a-new-kubernetes-stack-from-a-url.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateDockerStandaloneFile)Deploy a new compose stack from a file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerStandaloneFileDeploy-a-new-compose-stack-from-a-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateDockerStandaloneRepository)Deploy a new compose stack from repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerStandaloneRepositoryDeploy-a-new-compose-stack-from-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateDockerStandaloneString)Deploy a new compose stack from a text](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerStandaloneStringDeploy-a-new-compose-stack-from-a-text.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateDockerSwarmFile)Deploy a new swarm stack from a file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerSwarmFileDeploy-a-new-swarm-stack-from-a-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateDockerSwarmRepository)Deploy a new swarm stack from a git repository](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerSwarmRepositoryDeploy-a-new-swarm-stack-from-a-git-repository.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackCreateDockerSwarmString)Deploy a new swarm stack from a text](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackCreateDockerSwarmStringDeploy-a-new-swarm-stack-from-a-text.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StackDeleteKubernetesByName)Remove Kubernetes stacks by name](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStackDeleteKubernetesByNameRemove-Kubernetes-stacks-by-name.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/stacks/operation/StacksWebhookInvoke)Webhook for triggering stack updates from git](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstacksoperationStacksWebhookInvokeWebhook-for-triggering-stack-updates-from-git.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/status)status](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstatusstatus.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/status/operation/StatusInspect)Check Portainer status  Deprecated](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagstatusoperationStatusInspectCheck-Portainer-status--Deprecated.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/system)system](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemsystem.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/system/operation/systemInfo)Retrieve system info](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemInfoRetrieve-system-info.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/system/operation/systemNodesCount)Retrieve the count of nodes](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemNodesCountRetrieve-the-count-of-nodes.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/system/operation/systemStatus)Check Portainer status](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemStatusCheck-Portainer-status.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/system/operation/systemUpdate)Update Portainer to latest version](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemUpdateUpdate-Portainer-to-latest-version.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/system/operation/systemVersion)Check for portainer updates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsystemoperationsystemVersionCheck-for-portainer-updates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/tags)tags](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagstags.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/tags/operation/TagList)List tags](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagsoperationTagListList-tags.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/tags/operation/TagCreate)Create a new tag](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagsoperationTagCreateCreate-a-new-tag.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/tags/operation/TagDelete)Remove a tag](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtagsoperationTagDeleteRemove-a-tag.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/team_memberships)team_memberships](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsteam_memberships.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/team_memberships/operation/TeamMembershipList)List team memberships](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipListList-team-memberships.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/team_memberships/operation/TeamMembershipCreate)Create a new team membership](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipCreateCreate-a-new-team-membership.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/team_memberships/operation/TeamMembershipDelete)Remove a team membership](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipDeleteRemove-a-team-membership.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/team_memberships/operation/TeamMembershipUpdate)Update a team membership](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipUpdateUpdate-a-team-membership.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/team_memberships/operation/TeamMemberships)List team memberships](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteam_membershipsoperationTeamMembershipsList-team-memberships.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/teams)teams](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsteams.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/teams/operation/TeamList)List teams](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamListList-teams.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/teams/operation/TeamCreate)Create a new team](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamCreateCreate-a-new-team.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/teams/operation/TeamDelete)Remove a team](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamDeleteRemove-a-team.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/teams/operation/TeamInspect)Inspect a team](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamInspectInspect-a-team.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/teams/operation/TeamUpdate)Update a team](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagteamsoperationTeamUpdateUpdate-a-team.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/templates)templates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtemplatestemplates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/templates/operation/TemplateList)List available templates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtemplatesoperationTemplateListList-available-templates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/templates/operation/TemplateFile)Get a template's file](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagtemplatesoperationTemplateFileGet-a-templates-file.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/upload)upload](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguploadupload.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/upload/operation/UploadTLS)Upload TLS files](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguploadoperationUploadTLSUpload-TLS-files.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users)users](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersusers.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserList)List users](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserListList-users.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserCreate)Create a new user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserCreateCreate-a-new-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserDelete)Remove a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserDeleteRemove-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserInspect)Inspect a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserInspectInspect-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserUpdate)Update a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserUpdateUpdate-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserGetGitCredentials)Get all saved git credentials for a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGetGitCredentialsGet-all-saved-git-credentials-for-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserCreateGitCredential)Store a Git Credential for a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserCreateGitCredentialStore-a-Git-Credential-for-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserRemoveGitCredential)Remove a git-credential associated to a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserRemoveGitCredentialRemove-a-git-credential-associated-to-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserGetGitCredential)Get the specific saved git credential for a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGetGitCredentialGet-the-specific-saved-git-credential-for-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserUpdateGitCredential)Update a git-credential associated to a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserUpdateGitCredentialUpdate-a-git-credential-associated-to-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserMembershipsInspect)Inspect a user memberships](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserMembershipsInspectInspect-a-user-memberships.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserNamespaces)Retrieves all k8s namespaces for an user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserNamespacesRetrieves-all-k8s-namespaces-for-an-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserUpdatePassword)Update password for a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserUpdatePasswordUpdate-password-for-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserGetAPIKeys)Get all API keys for a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGetAPIKeysGet-all-API-keys-for-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserGenerateAPIKey)Generate an API key for a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserGenerateAPIKeyGenerate-an-API-key-for-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserRemoveAPIKey)Remove an api-key associated to a user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserRemoveAPIKeyRemove-an-api-key-associated-to-a-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserAdminCheck)Check administrator account existence](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserAdminCheckCheck-administrator-account-existence.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserAdminInit)Initialize administrator account](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationUserAdminInitInitialize-administrator-account.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/CurrentUserInspect)Inspect the current user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationCurrentUserInspectInspect-the-current-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/CurrentUserEndpointAuthorizationsInspect)Inspect environment authorizations for the current user](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagusersoperationCurrentUserEndpointAuthorizationsInspectInspect-environment-authorizations-for-the-current-user.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks)webhooks](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookswebhooks.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks/paths/~1webhooks/get)List webhooks](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooksgetList-webhooks.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks/paths/~1webhooks/post)Create a webhook](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhookspostCreate-a-webhook.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks/paths/~1webhooks~1{id}/delete)Delete a webhook](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1iddeleteDelete-a-webhook.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks/paths/~1webhooks~1{id}/post)Execute a webhook](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1idpostExecute-a-webhook.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks/paths/~1webhooks~1{id}/put)Update a webhook](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1idputUpdate-a-webhook.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks/paths/~1webhooks~1{id}~1reassign/put)Reassign a webhook to another resource](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebhookspaths1webhooks1id1reassignputReassign-a-webhook-to-another-resource.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/websocket)websocket](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketwebsocket.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/websocket/paths/~1websocket~1attach/get)Attach a websocket](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1attachgetAttach-a-websocket.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/websocket/paths/~1websocket~1exec/get)Execute a websocket](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1execgetExecute-a-websocket.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/websocket/paths/~1websocket~1kubernetes-shell/get)Execute a websocket on kubectl shell pod](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1kubernetes-shellgetExecute-a-websocket-on-kubectl-shell-pod.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/websocket/paths/~1websocket~1microk8s-shell/get)Connect to a remote SSH Shell via a websocket](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1microk8s-shellgetConnect-to-a-remote-SSH-Shell-via-a-websocket.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/websocket/paths/~1websocket~1pod/get)Execute a websocket on pod](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagwebsocketpaths1websocket1podgetExecute-a-websocket-on-pod.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/auto_updates)auto_updates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauto_updatesauto_updates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/auto_updates/operation/AutoUpdateList)List auto updates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagauto_updatesoperationAutoUpdateListList-auto-updates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials)cloud_credentials](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialscloud_credentials.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/getAll)getAll cloud credentials](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationgetAllgetAll-cloud-credentials.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/Create)Create a cloud credential](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationCreateCreate-a-cloud-credential.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/cloudCredsDelete)Delete a cloud credential](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationcloudCredsDeleteDelete-a-cloud-credential.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/cloudCredsGetByID)getByID gets a cloud credential by ID](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationcloudCredsGetByIDgetByID-gets-a-cloud-credential-by-ID.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/cloudCredsUpdate)Update a cloud credential](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationcloudCredsUpdateUpdate-a-cloud-credential.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/SharedGitGetAll)Get Shared Git Credentials](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitGetAllGet-Shared-Git-Credentials.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/SharedGitCreate)Create Shared Git Credential](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitCreateCreate-Shared-Git-Credential.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/SharedGitDelete)Delete Shared Git Credential](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitDeleteDelete-Shared-Git-Credential.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/SharedGitGet)Get Shared Git Credential](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitGetGet-Shared-Git-Credential.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/SharedGitUpdate)Update a Shared Git Credential](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationSharedGitUpdateUpdate-a-Shared-Git-Credential.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/Generate)Generate ssh keypair](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagcloud_credentialsoperationGenerateGenerate-ssh-keypair.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs)edge_configs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsedge_configs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs/operation/EdgeConfigList)List available Edge Configurations](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigListList-available-Edge-Configurations.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs/operation/EdgeConfigCreate)Create an Edge Configuration](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigCreateCreate-an-Edge-Configuration.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs/operation/EdgeConfigDelete)Delete an Edge configuration](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigDeleteDelete-an-Edge-configuration.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs/operation/EdgeConfigInspect)Inspect an Edge configuration](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigInspectInspect-an-Edge-configuration.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs/operation/EdgeConfigUpdate)Update an Edge Configuration](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigUpdateUpdate-an-Edge-Configuration.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs/operation/EdgeConfigState)Update the state of an Edge configuration](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigStateUpdate-the-state-of-an-Edge-configuration.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_configs/operation/EdgeConfigFiles)Get the files for an Edge configuration](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_configsoperationEdgeConfigFilesGet-the-files-for-an-Edge-configuration.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules)edge_update_schedules](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesedge_update_schedules.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleList)Fetches the list of Edge Update Schedules](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleListFetches-the-list-of-Edge-Update-Schedules.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleCreate)Creates a scheduled remote update procedure for Edge agents](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleCreateCreates-a-scheduled-remote-update-procedure-for-Edge-agents.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleDelete)Deletes an Edge Update Schedule](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleDeleteDeletes-an-Edge-Update-Schedule.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleInspect)Returns the Edge Update Schedule with the given ID](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleInspectReturns-the-Edge-Update-Schedule-with-the-given-ID.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleUpdate)Update a scheduled remote update procedure for Edge agents](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleUpdateUpdate-a-scheduled-remote-update-procedure-for-Edge-agents.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleActiveSchedulesList)Fetches the list of Active Edge Update Schedules](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleActiveSchedulesListFetches-the-list-of-Active-Edge-Update-Schedules.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/RemoteUpdatesAgentVersions)Fetches the supported versions of the agent to update/rollback](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationRemoteUpdatesAgentVersionsFetches-the-supported-versions-of-the-agent-to-updaterollback.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleInfo)Returns informations the help create edge update schedules](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdateScheduleInfoReturns-informations-the-help-create-edge-update-schedules.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdatePreviousVersions)Fetches the previous versions of updated agents](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagedge_update_schedulesoperationEdgeUpdatePreviousVersionsFetches-the-previous-versions-of-updated-agents.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/license)license](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenselicense.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/license/operation/licensesList)fetches the list of licenses on Portainer](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesListfetches-the-list-of-licenses-on-Portainer.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/license/operation/licensesAttach)attaches a list of licenses to Portainer](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesAttachattaches-a-list-of-licenses-to-Portainer.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/license/operation/licensesInfo)summarizes licenses on Portainer](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesInfosummarizes-licenses-on-Portainer.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/license/operation/licensesDelete)delete license from portainer instance](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taglicenseoperationlicensesDeletedelete-license-from-portainer-instance.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability)observability](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityobservability.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/GetAlerts)Get active or silenced alerts](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAlertsGet-active-or-silenced-alerts.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/TestAlertManagerConnectivity)Test AlertManager connectivity](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationTestAlertManagerConnectivityTest-AlertManager-connectivity.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/GetAllAlertRules)Get all alert rules](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAllAlertRulesGet-all-alert-rules.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/DeleteAlertRule)Delete an alert rule](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationDeleteAlertRuleDelete-an-alert-rule.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/GetAlertRule)Get an alert rule by ID](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAlertRuleGet-an-alert-rule-by-ID.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/UpdateAlertRule)Update an alert rule](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationUpdateAlertRuleUpdate-an-alert-rule.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/GetAllAlertingSettings)Get all alerting settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAllAlertingSettingsGet-all-alerting-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/UpdateAlertingSettings)Update alerting settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationUpdateAlertingSettingsUpdate-alerting-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/GetAlertingSettings)Get alerting settings by ID](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationGetAlertingSettingsGet-alerting-settings-by-ID.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/CreateSilence)Create an alert silence](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationCreateSilenceCreate-an-alert-silence.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/observability/operation/DeleteSilence)Delete an alert silence](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagobservabilityoperationDeleteSilenceDelete-an-alert-silence.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies)policies](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciespolicies.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyList)List policies](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyListList-policies.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyCreate)Create a new policy](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyCreateCreate-a-new-policy.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyDelete)Delete a policy](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyDeleteDelete-a-policy.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyInspect)Inspect a policy](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyInspectInspect-a-policy.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyUpdate)Update a policy](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyUpdateUpdate-a-policy.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyConflicts)Get policy conflicts preview](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyConflictsGet-policy-conflicts-preview.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyMetadata)Get policy metadata](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyMetadataGet-policy-metadata.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyTemplateList)List policy templates](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyTemplateListList-policy-templates.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/policies/operation/PolicyTemplateInspect)Inspect a policy template](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagpoliciesoperationPolicyTemplateInspectInspect-a-policy-template.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ssl)ssl](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsslssl.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ssl/operation/SSLInspect)Inspect the ssl settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagssloperationSSLInspectInspect-the-ssl-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/ssl/operation/SSLUpdate)Update the ssl settings](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagssloperationSSLUpdateUpdate-the-ssl-settings.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/support)support](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportsupport.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/support/operation/GetDebugLogStatus)Get status of the global debug log](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportoperationGetDebugLogStatusGet-status-of-the-global-debug-log.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/support/operation/SetDebugLogStatus)Enables or disables the global debug log](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportoperationSetDebugLogStatusEnables-or-disables-the-global-debug-log.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/support/operation/SupportBundleDownload)Download a bundle of files to help support diagnose issues](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0tagsupportoperationSupportBundleDownloadDownload-a-bundle-of-files-to-help-support-diagnose-issues.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/useractivity)useractivity](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityuseractivity.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/useractivity/operation/AuthLogsList)List auth activity logs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationAuthLogsListList-auth-activity-logs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/useractivity/operation/AuthLogsCSV)Download auth logs as CSV](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationAuthLogsCSVDownload-auth-logs-as-CSV.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/useractivity/operation/LogsList)List user activity logs](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationLogsListList-user-activity-logs.md>)
  - [[](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/useractivity/operation/LogsCSV)Download user activity logs as CSV](<./PortainerEE-API-2.39.0/httpsapi-docs.portainer.ioeditioneeversion2.39.0taguseractivityoperationLogsCSVDownload-user-activity-logs-as-CSV.md>)
